<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>DimRegen</name>
    <message>
        <location filename="../DimRegen.js" line="+64"/>
        <source>No dimension entities with custom label positions selected.</source>
        <translation>Keine Bemassungen mit Benutzerdefinierter Beschriftungsposition ausgewählt.</translation>
    </message>
    <message numerus="yes">
        <location line="+3"/>
        <source>Label position of %n dimension(s) was reset.</source>
        <translation>
            <numerusform>Beschriftungsposition von einer Bemassung zurückgesetzt.</numerusform>
            <numerusform>Beschriftungsposition von %n Bemassungen zurückgesetzt.</numerusform>
        </translation>
    </message>
    <message>
        <source>Reset label position of %1 dimension(s).</source>
        <translation type="vanished">Beschriftungsposition von %1 Bemassung(en) zurückgesetzt.</translation>
    </message>
    <message>
        <location filename="../DimRegenInit.js" line="+2"/>
        <source>&amp;Reset Label Position</source>
        <translation>Beschriftungsposition &amp;zurücksetzten</translation>
    </message>
</context>
</TS>
